
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef locoDemo_MSG_LIB_H
#define locoDemo_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "locoDemoType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  LOCODEMO_MBOX_NAME                  genomInstanceName("locoDemo")

#define  LOCODEMO_MAX_RQST_SIZE              128

#define  LOCODEMO_MBOX_RQST_SIZE       \
 (BUF_SIZE(LOCODEMO_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  LOCODEMO_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  LOCODEMO_MAX_REPLY_SIZE             128

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  LOCODEMO_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(LOCODEMO_MAX_REPLY_SIZE) \
   + BUF_SIZE(LOCODEMO_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define LOCODEMO_GETCONFIG_RQST 0
#define LOCODEMO_SETCONFIG_RQST 1
#define LOCODEMO_GETREF_RQST 2
#define LOCODEMO_SETREF_RQST 3
#define LOCODEMO_GETCMDPARAM_RQST 4
#define LOCODEMO_SETCMDPARAM_RQST 5
#define LOCODEMO_STOP_RQST 6
#define LOCODEMO_TRACK_RQST 7
#define LOCODEMO_SURVLINE_RQST 8
#define LOCODEMO_SETPOM_RQST 9
#define LOCODEMO_ABORT_RQST 10


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS locoDemoClientInit (CLIENT_ID *pClientId);

STATUS locoDemoClientEnd (CLIENT_ID clientId);

int locoDemoAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int locoDemoAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int locoDemoAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS locoDemoGetConfigRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int locoDemoGetConfigReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GENPOS_CART_STATE *(out_robot),
			       int *bilan);

int locoDemoGetConfigRqstAndRcv (CLIENT_ID clientId, 
				  
				 GENPOS_CART_STATE *(out_robot),
				 int *bilan);




extern STATUS locoDemoSetConfigRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_STATE *(in_robot),
					 int replyTimeOut);

int locoDemoSetConfigReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int locoDemoSetConfigRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_STATE *(in_robot), 
				 
				 int *bilan);




extern STATUS locoDemoGetRefRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int locoDemoGetRefReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GENPOS_CART_REF *(out_ref),
			       int *bilan);

int locoDemoGetRefRqstAndRcv (CLIENT_ID clientId, 
				  
				 GENPOS_CART_REF *(out_ref),
				 int *bilan);




extern STATUS locoDemoSetRefRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_REF *(in_ref),
					 int replyTimeOut);

int locoDemoSetRefReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int locoDemoSetRefRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_REF *(in_ref), 
				 
				 int *bilan);




extern STATUS locoDemoGetCmdParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int locoDemoGetCmdParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GENPOS_CART_CMD_PARAM *(out_cmd),
			       int *bilan);

int locoDemoGetCmdParamRqstAndRcv (CLIENT_ID clientId, 
				  
				 GENPOS_CART_CMD_PARAM *(out_cmd),
				 int *bilan);




extern STATUS locoDemoSetCmdParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_CMD_PARAM *(in_cmd),
					 int replyTimeOut);

int locoDemoSetCmdParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int locoDemoSetCmdParamRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_CMD_PARAM *(in_cmd), 
				 
				 int *bilan);




extern STATUS locoDemoStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int locoDemoStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int locoDemoStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS locoDemoTrackRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GENPOS_POSTER_NAME *(in_posterName),
					 int replyTimeOut);

extern int locoDemoTrackReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int locoDemoTrackRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GENPOS_POSTER_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int locoDemoTrackRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GENPOS_POSTER_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS locoDemoSurvLineRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SURV_LINE_STR *(in_survLineStr),
					 int replyTimeOut);

extern int locoDemoSurvLineReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int locoDemoSurvLineRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SURV_LINE_STR *(in_survLineStr), 
					
					int *activity, int *bilan);

extern int locoDemoSurvLineRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SURV_LINE_STR *(in_survLineStr), 
					
					int *activity,
					int *bilan);




extern STATUS locoDemoSetPomRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GENPOS_POSTER_NAME *(in_mePosterName),
					 int replyTimeOut);

extern int locoDemoSetPomReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int locoDemoSetPomRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GENPOS_POSTER_NAME *(in_mePosterName), 
					
					int *activity, int *bilan);

extern int locoDemoSetPomRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GENPOS_POSTER_NAME *(in_mePosterName), 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* locoDemo_MSG_LIB_H */

